package eu.etaxonomy.taxeditor.editor;

import org.eclipse.core.resources.IMarker;
import org.eclipse.jface.text.Position;
import org.eclipse.jface.text.source.Annotation;
import org.eclipse.jface.text.source.IAnnotationPresentation;
import org.eclipse.swt.graphics.GC;
import org.eclipse.swt.graphics.Image;
import org.eclipse.swt.graphics.Point;
import org.eclipse.swt.graphics.RGB;
import org.eclipse.swt.graphics.Rectangle;
import org.eclipse.swt.widgets.Canvas;

import eu.etaxonomy.taxeditor.ITaxEditorConstants;
import eu.etaxonomy.taxeditor.TaxEditorPlugin;

public class ErrorAnnotation extends Annotation implements IAnnotationPresentation {
    private IMarker marker;
    private String text;
    private int line;
    private Position position;

    // error identifiers, images and colors
    public static String ERROR_TYPE = "error.type";
    public static Image ERROR_IMAGE = TaxEditorPlugin.getDefault().getImage(ITaxEditorConstants.ACTIVE_DELETE_ICON);
    public static final RGB ERROR_RGB = new RGB(255, 0, 0);    
    
    public ErrorAnnotation(IMarker marker) {
        this.marker = marker;
    }

    public ErrorAnnotation(int line, String text) {
    	super(ERROR_TYPE, false, text);
        this.marker = null;
        this.line = line;
        this.text = text;
    }

    public IMarker getMarker() {
        return marker;
    }

    public int getLine() {
        return line;
    }

    public String getText() {
        return "Error in the string " + text;
    }

    public int getLayer() {
        return 3;
    }

    public String getType() {
        return ERROR_TYPE;
    }

    public Position getPosition() {
        return position;
    }

    public void setPosition(Position position) {
        this.position = position;
    }

	
	public void paint(GC gc, Canvas canvas, Rectangle bounds) {
		Point canvasSize= canvas.getSize();

		int x= 0;
		int y= bounds.y;
		int w= canvasSize.x;
		int h= bounds.height;

		if (y + h > canvasSize.y)
			h= canvasSize.y - y;

		if (y < 0) {
			h= h + y;
			y= 0;
		}

		if (h <= 0)
			return;

		Image image = TaxEditorPlugin
							.getDefault().getImage(ITaxEditorConstants.ERROR_ANNOTATION_ICON);
		
		Rectangle r = image.getBounds();
		
		int destX = x + w - r.width;
		int destY = y + h - r.height;
		
		gc.drawImage(image, 0, 0, r.width, r.height, destX, destY, r.width, r.height);
	}
}