/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.navigation;

import org.apache.log4j.Logger;

import eu.etaxonomy.cdm.model.name.NonViralName;
import eu.etaxonomy.cdm.model.reference.ReferenceBase;
import eu.etaxonomy.cdm.model.taxon.Taxon;

/**
 * A singleton used as a placeholder in the taxonomic tree when user executes the 
 * action "Add taxon with quick name". When the user enters a valid (i.e. non "") 
 * string, the node is replaced with a taxon. Note that this should not be added to
 * the session data repository, nor should it be added to its parent taxon's 
 * taxonomic children.
 * 
 * @see TaxonomicTreeViewer
 * @see TaxonomicTreeContentProvider
 * 
 * @author p.ciardelli
 * @created 03.02.2009
 * @version 1.0
 */
public class QuickNameTaxon extends Taxon {
	private static final Logger logger = Logger.getLogger(QuickNameTaxon.class);
	
	private static QuickNameTaxon instance = null;

	private Taxon parentTaxon;
	
	private QuickNameTaxon(NonViralName name, ReferenceBase sec) {
		super(name, sec);
	}

	public static QuickNameTaxon getInstance() {
		if (instance == null) {
			instance = new QuickNameTaxon(null, null);
		}
		return instance;
	}

	public ReferenceBase getSec() {
		if (parentTaxon == null) {
			return null;
		} else {
			return parentTaxon.getSec();
		}
	}
	
	public void setParent(Taxon parentTaxon) {
		this.parentTaxon = parentTaxon;
	}
	
	public Taxon getTaxonomicParent() {
		return parentTaxon;
	}
}