/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.operations.description;

import org.apache.log4j.Logger;
import org.eclipse.core.commands.ExecutionException;
import org.eclipse.core.commands.operations.IUndoContext;
import org.eclipse.core.runtime.IAdaptable;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.core.runtime.IStatus;

import eu.etaxonomy.cdm.model.description.Feature;
import eu.etaxonomy.cdm.model.description.TaxonDescription;
import eu.etaxonomy.cdm.model.description.TextData;
import eu.etaxonomy.cdm.model.taxon.Taxon;
import eu.etaxonomy.taxeditor.operations.AbstractEditorOperation;

/**
 * @author p.ciardelli
 * @created 05.02.2009
 * @version 1.0
 */
public class AddElementOperation extends AbstractEditorOperation {
	private static final Logger logger = Logger
			.getLogger(AddElementOperation.class);
	
	private TaxonDescription description;
	private Feature feature;
	private TextData element;

	public AddElementOperation(String label, IUndoContext undoContext,
			Taxon taxon, TaxonDescription description, Feature feature) {
		super(label, undoContext, taxon);
		
		this.description = description;
		this.feature = feature;
	}

	/* (non-Javadoc)
	 * @see org.eclipse.core.commands.operations.AbstractOperation#execute(org.eclipse.core.runtime.IProgressMonitor, org.eclipse.core.runtime.IAdaptable)
	 */
	@Override
	public IStatus execute(IProgressMonitor monitor, IAdaptable info)
			throws ExecutionException {
		
		element = TextData.NewInstance(feature);
		description.addElement(element);
		
		// Redraw editor if exists
		return redrawOpenEditor();
	}

	/* (non-Javadoc)
	 * @see org.eclipse.core.commands.operations.AbstractOperation#redo(org.eclipse.core.runtime.IProgressMonitor, org.eclipse.core.runtime.IAdaptable)
	 */
	@Override
	public IStatus redo(IProgressMonitor monitor, IAdaptable info)
			throws ExecutionException {
		
		description.addElement(element);
		
		// Redraw editor if exists
		return redrawOpenEditor();
	}

	/* (non-Javadoc)
	 * @see org.eclipse.core.commands.operations.AbstractOperation#undo(org.eclipse.core.runtime.IProgressMonitor, org.eclipse.core.runtime.IAdaptable)
	 */
	@Override
	public IStatus undo(IProgressMonitor monitor, IAdaptable info)
			throws ExecutionException {
		
		description.removeElement(element);
		
		// Redraw editor if exists
		return redrawOpenEditor();
	}
}
