/**
* Copyright (C) 2009 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.propertysheet.type.wizard;

import org.apache.log4j.Logger;
import org.eclipse.jface.wizard.WizardPage;
import org.eclipse.swt.SWT;
import org.eclipse.swt.custom.CCombo;
import org.eclipse.swt.events.KeyEvent;
import org.eclipse.swt.events.KeyListener;
import org.eclipse.swt.events.SelectionAdapter;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Label;
import org.eclipse.swt.widgets.Text;

import eu.etaxonomy.cdm.model.name.SpecimenTypeDesignation;
import eu.etaxonomy.cdm.model.name.TaxonNameBase;
import eu.etaxonomy.cdm.model.name.TypeDesignationStatus;
import eu.etaxonomy.taxeditor.model.CdmSessionDataRepository;

/**
 * @author p.ciardelli
 * @created 13.02.2009
 * @version 1.0
 */
public class ChooseTypeDesignationWizardPage extends WizardPage {
	private static Logger logger = Logger
			.getLogger(ChooseTypeDesignationWizardPage.class);
	
	private SpecimenTypeDesignation typeDesignation;
	private CCombo statusCombo;

	private Text txtDesignationType;

	/**
	 * @param typeDesignation
	 */
	public ChooseTypeDesignationWizardPage(
			SpecimenTypeDesignation typeDesignation, TaxonNameBase name) {
		super("");
		
		this.typeDesignation = typeDesignation;
		
		setTitle("Create or edit type designation");
		setDescription("Create or edit type designation for '" + name.getTitleCache() + "\".");
	}

	/* (non-Javadoc)
	 * @see org.eclipse.jface.dialogs.IDialogPage#createControl(org.eclipse.swt.widgets.Composite)
	 */
	@Override
	public void createControl(Composite parent) {
		
		// Create composite for popup dialog	
		Composite container = new Composite(parent, SWT.NULL);
		final GridLayout gridLayout = new GridLayout();
		container.setLayout(gridLayout);
		setControl(container);

		// Create text
		final Label lblChooseStatus = new Label(container, SWT.NONE);
		lblChooseStatus.setText("Choose designation type status:");

		// Create designation type status dropdown 
		statusCombo = new CCombo(container, SWT.BORDER);
		statusCombo.setLayoutData(new GridData(SWT.FILL, SWT.CENTER, true, false));
		for (TypeDesignationStatus typeStatus : 
				CdmSessionDataRepository.getDefault().getTypeDesignationStatus()) {
						
			String label = typeStatus.getLabel();
//			String label = "placeholder";
			statusCombo.add(label);
		}

		statusCombo.addSelectionListener(new SelectionAdapter() {
			@Override
			public void widgetSelected(SelectionEvent e) {
//				int typeIndex = typeCombo.getSelectionIndex();
//				relationModel.setType(relationTypes.get(typeIndex));
				updatePage();
			}
		});

		// Create text
		final Label lblEnterText = new Label(container, SWT.NONE);
		lblEnterText.setText("Enter designation type text:");
		
		txtDesignationType = new Text(container, SWT.BORDER);
		txtDesignationType.setLayoutData(new GridData(SWT.FILL, SWT.FILL, true, true));
		txtDesignationType.addKeyListener(new KeyListener() {

			@Override
			public void keyPressed(KeyEvent e) {}

			@Override
			public void keyReleased(KeyEvent e) {
				updatePage();
			}			
		});
	}

	@Override
	public boolean canFlipToNextPage() {
		return isPageComplete();
	}

	public boolean isPageComplete() {
		return (statusCombo.getSelectionIndex() > -1 
				&& txtDesignationType.getText().length() > 0);
	}
	
	private void updatePage() {
		getWizard().getContainer().updateButtons();
	}
}
